@@ -37,11 +37,11 @@ void CEventLoop::SendEvent(CEventHandler* handler, CEventBase* evt)
 				cond_.signal(lock);
 			}
 			pending_events_.emplace_back(handler, evt);			
-		}
-		else {
-			delete evt;
+			return;
 		}
 	}
+
+	delete evt;
 }
 
 void CEventLoop::RemoveHandler(CEventHandler* handler)
@@ -81,7 +81,7 @@ void CEventLoop::RemoveHandler(CEventHandler* handler)
 	}
 }
 
-void CEventLoop::FilterEvents(std::function<bool(Events::value_type &)> filter)
+void CEventLoop::FilterEvents(std::function<bool(Events::value_type &)> const& filter)
 {
 	scoped_lock l(sync_);
 
@@ -99,19 +99,18 @@ void CEventLoop::FilterEvents(std::function<bool(Events::value_type &)> filter)
 	);
 }
 
-timer_id CEventLoop::AddTimer(CEventHandler* handler, int ms_interval, bool one_shot)
+timer_id CEventLoop::AddTimer(CEventHandler* handler, duration const& interval, bool one_shot)
 {
 	timer_data d;
 	d.handler_ = handler;
 	if (!one_shot) {
-		d.ms_interval_ = ms_interval;
+		d.interval_ = interval;
 	}
-	d.deadline_ = CMonotonicClock::now() + ms_interval;
+	d.deadline_ = CMonotonicClock::now() + interval;
 
 	scoped_lock lock(sync_);
-	static timer_id id{};
 	if (!handler->removing_) {
-		d.id_ = ++id; // 64bit, can this really ever overflow?
+		d.id_ = ++next_timer_id_; // 64bit, can this really ever overflow?
 
 		timers_.emplace_back(d);
 		if (!deadline_ || d.deadline_ < deadline_) {
@@ -179,7 +178,7 @@ wxThread::ExitCode CEventLoop::Entry()
 
 		// Nothing to do, now we wait
 		if (deadline_) {
-			int wait = static_cast<int>(deadline_ - now);
+			int wait = static_cast<int>((deadline_ - now).get_milliseconds());
 			cond_.wait(l, wait);
 		}
 		else {
@@ -223,11 +222,11 @@ bool CEventLoop::ProcessTimers(scoped_lock & l, CMonotonicClock const& now)
 		auto const id = it->id_;
 			
 		// Update the expired timer
-		if (!it->ms_interval_) {
+		if (!it->interval_) {
 			timers_.erase(it);
 		}
 		else {
-			it->deadline_ = std::move(now + it->ms_interval_);
+			it->deadline_ = std::move(now + it->interval_);
 			if (!deadline_ || it->deadline_ < deadline_) {
 				deadline_ = it->deadline_;
 			}
