@@ -92,7 +92,7 @@ wxString CBuildInfo::GetBuildType()
 	return wxString();
 }
 
-wxLongLong CBuildInfo::ConvertToVersionNumber(const wxChar* version)
+int64_t CBuildInfo::ConvertToVersionNumber(const wxChar* version)
 {
 	// Crude conversion from version string into number for easy comparison
 	// Supported version formats:
@@ -119,27 +119,22 @@ wxLongLong CBuildInfo::ConvertToVersionNumber(const wxChar* version)
 	if (*version < '0' || *version > '9')
 		return -1;
 
-	wxLongLong v = 0;
-	int segment = 0;
+	int64_t v{};
+	int segment{};
+	int shifts{};
 
-	int shifts = 0;
-
-	for (; *version; version++)
-	{
-		if (*version == '.' || *version == '-' || *version == 'b')
-		{
+	for (; *version; ++version) {
+		if (*version == '.' || *version == '-' || *version == 'b') {
 			v += segment;
 			segment = 0;
 			v <<= 10;
 			shifts++;
 		}
-		if (*version == '-' && shifts < 4)
-		{
+		if (*version == '-' && shifts < 4) {
 			v <<= (4 - shifts) * 10;
 			shifts = 4;
 		}
-		else if (*version >= '0' && *version <= '9')
-		{
+		else if (*version >= '0' && *version <= '9') {
 			segment *= 10;
 			segment += *version - '0';
 		}
@@ -184,3 +179,72 @@ bool CBuildInfo::IsUnstable()
 
 	return false;
 }
+
+
+#if defined(__i386__) || defined(__x86_64__) || defined(_M_X64) || defined(_M_IX86)
+#define HAVE_CPUID 1
+#endif
+
+#if HAVE_CPUID
+
+#ifdef _MSC_VER
+namespace {
+	void cpuid(int f, int sub, int reg[4])
+	{
+		__cpuidex(reg, f, sub);
+	}
+}
+#else
+#include <cpuid.h>
+namespace {
+	void cpuid(int f, int sub, int reg[4])
+	{
+		__cpuid_count(f, sub, reg[0], reg[1], reg[2], reg[3]);
+	}
+}
+#endif
+#endif
+
+wxString CBuildInfo::GetCPUCaps(char separator)
+{
+	wxString ret;
+
+#if HAVE_CPUID
+	int reg[4];
+	cpuid(0, 0, reg);
+
+	int const max = reg[0];
+
+	// function (aka leave), subfunction (subleave), register, bit, description
+	std::tuple<int, int, int, int, wxString> const caps[] = {
+		std::make_tuple(1, 0, 3, 25, _T("sse")),
+		std::make_tuple(1, 0, 3, 26, _T("sse2")),
+		std::make_tuple(1, 0, 2, 0,  _T("sse3")),
+		std::make_tuple(1, 0, 2, 9,  _T("ssse3")),
+		std::make_tuple(1, 0, 2, 19, _T("sse4.1")),
+		std::make_tuple(1, 0, 2, 20, _T("sse4.2")),
+		std::make_tuple(1, 0, 2, 28, _T("avx")),
+		std::make_tuple(7, 0, 1, 5,  _T("avx2")),
+		std::make_tuple(1, 0, 2, 25, _T("aes")),
+		std::make_tuple(1, 0, 2, 1,  _T("pclmulqdq")),
+		std::make_tuple(1, 0, 2, 30, _T("rdrnd")),
+		std::make_tuple(7, 0, 1, 3,  _T("bmi2")),
+		std::make_tuple(7, 0, 1, 8,  _T("bmi2")),
+		std::make_tuple(7, 0, 1, 19, _T("adx"))
+	};
+
+	for (auto const& cap : caps) {
+		if (max >= std::get<0>(cap)) {
+			cpuid(std::get<0>(cap), std::get<1>(cap), reg);
+			if (reg[std::get<2>(cap)] & (1 << std::get<3>(cap))) {
+				if (!ret.empty()) {
+					ret += separator;
+				}
+				ret += std::get<4>(cap);
+			}
+		}
+	}
+#endif
+
+	return ret;
+}
